gchecky.model.postal_area_t

Package gchecky :: Module model :: Class postal_area_t |
[hide private]
[frames] | no frames]

# Class postal_area_t

source code

    object --+
             |
     gxml.Node --+
                 |
                postal_area_t

    >>> test_node(postal_area_t(country_code = 'VU'),
    ... '''
    ... <node><country-code>VU</country-code></node>
    ... '''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| country_code = `CountryCode:PATH(country-code):REQ`
| postal_code_pattern = `String:PATH(postal-code-pattern):OPT`
| _fields = ``{``'``country_code``'``:` CountryCode:PATH(country-code):REQ`,``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'country_code': CountryCode:PATH(country-code):REQ,
       'postal_code_pattern': String:PATH(postal-code-pattern):OPT}